__author__ = "Daniel Peña Iglesias"
__copyright__ = "Copyright (C) 2023 Daniel Peña Iglesias"
__credits__ = ["Daniel Peña Iglesias"]
__license__ = "MIT"

from concurrent.futures import ThreadPoolExecutor
import asyncio
import multiprocessing
from functools import wraps 

default_executor = ThreadPoolExecutor(multiprocessing.cpu_count())

def asynciodize(default_fn=None, executor=default_executor):
    def wrapper_decorator(fn):
        @wraps(fn)
        async def wrapper_fn(*args, **kwargs):
            loop = asyncio.get_running_loop()
            return await loop.run_in_executor(executor, fn, *args, **kwargs)

        return wrapper_fn

    if default_fn is None:
        return wrapper_decorator
    else:
        return wrapper_decorator(default_fn)


from distutils.core import setup
setup(
  name = 'asynciodize',
  packages = ['asynciodize'],
  version = '0.1-beta.2',
  license='MIT',
  description = 'A package to wrap/decorate blocking functions for use in asyncIO',
  author = 'Daniel Peña Iglesias',
  author_email = 'danpeis@gmail.com',
  url = 'https://github.com/pibone/asynciodize',
  download_url = 'https://github.com/pibone/asynciodize/archive/refs/tags/v0.1-beta.2.tar.gz',    
  keywords = ['asyncio', 'blocking', 'multithreading'],   
  install_requires=['asyncio'],
  classifiers=[
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Libraries',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.9',
  ],
)


__author__ = "Daniel Peña Iglesias"
__copyright__ = "Copyright (C) 2023 Daniel Peña Iglesias"
__credits__ = ["Daniel Peña Iglesias"]
__license__ = "MIT"

from asynciodize.asynciodize import asynciodize